pub fn contact_manifold_halfspace_pfm_shapes<ManifoldData, ContactData>(
pos12: &Isometry<f64>,
shape1: &dyn Shape,
shape2: &dyn Shape,
prediction: f64,
manifold: &mut ContactManifold<ManifoldData, ContactData>,
)Expand description
Computes the contact manifold between a convex shape and a ball, both represented as a Shape trait-object.